added functional tests for hip device apis
[ROCm/hip commit: 7a0066eb6f]
Bu işleme şunda yer alıyor:
@@ -152,6 +152,8 @@ make_hip_executable (hipHostRegister hipHostRegister.cpp)
|
|||||||
make_hip_executable (hipRandomMemcpyAsync hipRandomMemcpyAsync.cpp)
|
make_hip_executable (hipRandomMemcpyAsync hipRandomMemcpyAsync.cpp)
|
||||||
make_hip_executable (hipMemoryAllocate hipMemoryAllocate.cpp)
|
make_hip_executable (hipMemoryAllocate hipMemoryAllocate.cpp)
|
||||||
make_hip_executable (hipFuncSetDeviceFlags hipFuncSetDeviceFlags.cpp)
|
make_hip_executable (hipFuncSetDeviceFlags hipFuncSetDeviceFlags.cpp)
|
||||||
|
make_hip_executable (hipFuncGetDevice hipFuncGetDevice.cpp)
|
||||||
|
make_hip_executable (hipFuncSetDevice hipFuncSetDevice.cpp)
|
||||||
|
|
||||||
make_test(hip_ballot " " )
|
make_test(hip_ballot " " )
|
||||||
make_test(hip_anyall " " )
|
make_test(hip_anyall " " )
|
||||||
@@ -190,4 +192,8 @@ make_test(hipRandomMemcpyAsync " ")
|
|||||||
#make_test(hipAPIStreamDisable " ")
|
#make_test(hipAPIStreamDisable " ")
|
||||||
make_test(hipMemoryAllocate " ")
|
make_test(hipMemoryAllocate " ")
|
||||||
make_test(hipFuncSetDeviceFlags " ")
|
make_test(hipFuncSetDeviceFlags " ")
|
||||||
|
make_test(hipFuncGetDevice " ")
|
||||||
|
make_test(hipFuncSetDevice " ")
|
||||||
|
|
||||||
|
|
||||||
make_hipify_test(specialFunc.cu )
|
make_hipify_test(specialFunc.cu )
|
||||||
|
|||||||
@@ -0,0 +1,51 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include"test_common.h"
|
||||||
|
|
||||||
|
#define _SIZE sizeof(int)*1024*1024
|
||||||
|
#define NUM_STREAMS 10
|
||||||
|
|
||||||
|
__global__ void Iter(hipLaunchParm lp, int *Ad, int num){
|
||||||
|
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
|
||||||
|
if(tx == 0){
|
||||||
|
for(int i = 0; i<num;i++){
|
||||||
|
Ad[tx] += 1;
|
||||||
|
}
|
||||||
|
}
|
||||||
|
}
|
||||||
|
|
||||||
|
int main(){
|
||||||
|
int *A[NUM_STREAMS];
|
||||||
|
int *Ad[NUM_STREAMS];
|
||||||
|
hipStream_t stream[NUM_STREAMS];
|
||||||
|
for(int i=0;i<NUM_STREAMS;i++){
|
||||||
|
A[i] = (int*)malloc(_SIZE);
|
||||||
|
A[i][0] = 1;
|
||||||
|
HIPCHECK(hipMalloc((void**)&Ad[i], _SIZE));
|
||||||
|
HIPCHECK(hipStreamCreate(&stream[i]));
|
||||||
|
}
|
||||||
|
for(int i=0;i<NUM_STREAMS;i++){
|
||||||
|
HIPCHECK(hipMemcpyAsync(Ad[i], A[i], _SIZE, hipMemcpyHostToDevice, stream[i]));
|
||||||
|
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, stream[i], Ad[i], 1<<30);
|
||||||
|
HIPCHECK(hipMemcpyAsync(A[i], Ad[i], _SIZE, hipMemcpyDeviceToHost, stream[i]));
|
||||||
|
}
|
||||||
|
HIPASSERT(1<<30 != A[NUM_STREAMS-1][0]-1);
|
||||||
|
}
|
||||||
|
|
||||||
@@ -0,0 +1,38 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
/*
|
||||||
|
* Conformance test for checking functionality of
|
||||||
|
* hipError_t hipGetDevice(int *device);
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include "test_common.h"
|
||||||
|
|
||||||
|
int main()
|
||||||
|
{
|
||||||
|
int numDevices = 0;
|
||||||
|
int device;
|
||||||
|
HIPCHECK(hipGetDeviceCount(&numDevices));
|
||||||
|
for(int i=0;i<numDevices;i++){
|
||||||
|
HIPCHECK(hipSetDevice(i));
|
||||||
|
HIPCHECK(hipGetDevice(&device));
|
||||||
|
HIPASSERT(device == i);
|
||||||
|
}
|
||||||
|
passed();
|
||||||
|
}
|
||||||
@@ -0,0 +1,30 @@
|
|||||||
|
/*
|
||||||
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
||||||
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||||
|
of this software and associated documentation files (the "Software"), to deal
|
||||||
|
in the Software without restriction, including without limitation the rights
|
||||||
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||||
|
copies of the Software, and to permit persons to whom the Software is
|
||||||
|
furnished to do so, subject to the following conditions:
|
||||||
|
The above copyright notice and this permission notice shall be included in
|
||||||
|
all copies or substantial portions of the Software.
|
||||||
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
||||||
|
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||||
|
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||||
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
|
||||||
|
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||||
|
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||||
|
THE SOFTWARE.
|
||||||
|
*/
|
||||||
|
|
||||||
|
#include "test_common.h"
|
||||||
|
|
||||||
|
int main(){
|
||||||
|
int numDevices = 0;
|
||||||
|
HIPCHECK(hipGetDeviceCount(&numDevices));
|
||||||
|
for(int i=0;i<numDevices;i++){
|
||||||
|
HIPCHECK(hipSetDevice(i));
|
||||||
|
}
|
||||||
|
HIPASSERT(hipErrorInvalidDevice == hipSetDevice(numDevices));
|
||||||
|
passed();
|
||||||
|
}
|
||||||
Yeni konuda referans
Bir kullanıcı engelle